@@ -33,7 +33,7 @@
 #include "style-editor.h"
 
 #define string_assign(dest, src) g_free ((*dest)); (*dest) = g_strdup ((src));
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-editor-scintilla.ui"
+#define GLADE_FILE PACKAGE_DATA_DIR "/glade/anjuta-editor-scintilla.ui"
 
 gchar *hilite_style[] = {
 	"Normal <Default>", "style.anjuta.normal",
@@ -572,7 +572,7 @@ on_hilite_style_entry_changed (GtkComboBox * combobox, gpointer user_data)
 	g_return_if_fail (user_data);
 	p = user_data;
 
-	style_item = gtk_combo_box_get_active_text (combobox);
+	style_item = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combobox));
 	if (!style_item || strlen (style_item) <= 0)
 		return;
 	if (p->priv->current_style)
@@ -849,8 +849,8 @@ apply_styles (StyleEditor *se)
 		fclose (ofile);
 		g_free (filename);
 	}
-	anjuta_preferences_set_int (se->prefs, DISABLE_SYNTAX_HILIGHTING, 1);
-	anjuta_preferences_set_int (se->prefs, DISABLE_SYNTAX_HILIGHTING, 0);
+	g_settings_set_int (se->settings, DISABLE_SYNTAX_HILIGHTING, 1);
+	g_settings_set_int (se->settings, DISABLE_SYNTAX_HILIGHTING, 0);
 }
 
 static void
@@ -883,6 +883,7 @@ create_style_editor_gui (StyleEditor * se)
 {
 	GtkBuilder *bxml = gtk_builder_new ();
 	GtkWidget *pref_dialog;
+	GtkListStore *store;
 	gint i;
 	GError* error = NULL;
 
@@ -912,14 +913,23 @@ create_style_editor_gui (StyleEditor * se)
 	se->priv->calltip_back_color = GTK_WIDGET (gtk_builder_get_object (bxml, "calltip"));
 	se->priv->selection_fore_color = GTK_WIDGET (gtk_builder_get_object (bxml, "selection_fore"));
 	se->priv->selection_back_color = GTK_WIDGET (gtk_builder_get_object (bxml, "selection_back"));
-	
+		
+	/* Fill combo box with modules */
+    store = gtk_list_store_new(1, G_TYPE_STRING);
+    gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (se->priv->hilite_item_combobox), 0);
+
 	for (i = 0;; i += 2)
 	{
+		GtkTreeIter iter;
+		
 		if (hilite_style[i] == NULL)
 			break;
-		gtk_combo_box_append_text (GTK_COMBO_BOX (se->priv->hilite_item_combobox), hilite_style[i]);
-
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter, 0, hilite_style[i], -1);
 	}
+    gtk_combo_box_set_model (GTK_COMBO_BOX(se->priv->hilite_item_combobox), GTK_TREE_MODEL(store));
+    g_object_unref (store);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (se->priv->hilite_item_combobox), 0);
 	
 	pref_dialog = anjuta_preferences_get_dialog (se->prefs);
 	gtk_window_set_transient_for (GTK_WINDOW (se->priv->dialog),
@@ -949,7 +959,7 @@ create_style_editor_gui (StyleEditor * se)
 }
 
 StyleEditor *
-style_editor_new (AnjutaPreferences *prefs)
+style_editor_new (AnjutaPreferences *prefs, GSettings *settings)
 {
 	StyleEditor *se;
 	se = g_new0 (StyleEditor, 1);
@@ -957,6 +967,7 @@ style_editor_new (AnjutaPreferences *prefs)
 	se->props = text_editor_get_props ();
 	se->priv->dialog = NULL;
 	se->prefs = prefs;
+	se->settings = g_object_ref (settings);
 	return se;
 }
 
@@ -966,6 +977,7 @@ void style_editor_destroy (StyleEditor *se)
 	if (se->priv->dialog)
 		gtk_widget_destroy (se->priv->dialog);
 	g_free (se->priv);
+	g_object_unref (se->settings);
 	g_free (se);
 }
 
